# -*- coding: utf-8 -*-

from plone.app.layout.viewlets.common import LogoViewlet as BaseLogoViewlet

class LogoViewlet(BaseLogoViewlet):
    """Customized version of the logo viewlet, where the logo URL is taken from the subsite"""

    def update(self):
        super(LogoViewlet, self).update()

        portal_url = self.portal_state.portal_url()
        
        # Commonly is '<img src="http://host/logo.png" alt="" title="" height="x" width="y" />'
        self.logo_tag = self.logo_tag.replace(portal_url, self.navigation_root_url)

        # BBB: is ok keeping the main site name?
        #self.portal_title = self.portal_state.portal_title()




# -*- coding: utf-8 -*-

from plone.theme.interfaces import IDefaultPloneLayer

class IFrontendLayer(IDefaultPloneLayer):
    """Marker interface that defines a Zope 3 browser layer.
       This is not developed to be directly used for layout registration, but
       all new skin layout that wanna be used in a subsites need to inherit from
       this interface.
    """



# -*- coding: utf-8 -*-

from Products.PythonScripts.standard import url_quote

from Products.ResourceRegistries.browser.styles import StylesView as BaseStylesView
from plone.app.layout.navigation.root import getNavigationRoot


class StylesView(BaseStylesView):
    """ Information for style rendering for a specific subsite section """

    def _getRegistryURL(self, registry):
        """Service method to get the right registry URL.
        This is constructed with the "/subsite" section if we are in a subsite enrironment.
        """
        subsite_path = getNavigationRoot(self.context)
        brains = self.context.portal_catalog(path={'query':subsite_path, 'depth':0})
        if brains:
            subsite = brains[0]
            registry_url = subsite.getURL() + '/portal_css'
        else:
            registry_url = registry.absolute_url()
        return registry_url

    def styles(self):
        registry = self.registry()
        registry_url = self._getRegistryURL(registry)

        styles = registry.getEvaluatedResources(self.context)
        skinname = url_quote(self.skinname())
        result = []
        for style in styles:
            rendering = style.getRendering()
            if rendering == 'link':
                src = "%s/%s/%s" % (registry_url, skinname, style.getId())
                data = {'rendering': rendering,
                        'media': style.getMedia(),
                        'rel': style.getRel(),
                        'title': style.getTitle(),
                        'conditionalcomment' : style.getConditionalcomment(),
                        'src': src}
            elif rendering == 'import':
                src = "%s/%s/%s" % (registry_url, skinname, style.getId())
                data = {'rendering': rendering,
                        'media': style.getMedia(),
                        'conditionalcomment' : style.getConditionalcomment(),
                        'src': src}
            elif rendering == 'inline':
                content = registry.getInlineResource(style.getId(),
                                                     self.context)
                data = {'rendering': rendering,
                        'media': style.getMedia(),
                        'conditionalcomment' : style.getConditionalcomment(),
                        'content': content}
            else:
                raise ValueError, "Unkown rendering method '%s' for style '%s'" % (rendering, style.getId())
            result.append(data)
        return result



# -*- coding: utf-8 -*-

from zope import interface, component
from p4a.subtyper import interfaces
from redturtle.subsites.backend.interfaces import ISubsiteRoot

class SubSiteDescriptor(object):
    interface.implements(interfaces.IPortalTypedFolderishDescriptor)
    title = u'Subsite'
    description = u'A subsite internal to the portal'
    type_interface = ISubsiteRoot
    for_portal_type = 'Folder'

component.provideUtility(SubSiteDescriptor(),
                         name=u'subsite')


# -*- coding: utf-8 -*-

from Acquisition import aq_inner
from Products.PythonScripts.standard import url_quote

from Products.ResourceRegistries.browser.scripts import ScriptsView as BaseScriptsView
from plone.app.layout.navigation.root import getNavigationRoot


class ScriptsView(BaseScriptsView):
    """ Information for script rendering. """

    def _getRegistryURL(self, registry):
        """Service method to get the right registry URL.
        This is constructed with the "/subsite" section if we are in a subsite enrironment.
        """
        subsite_path = getNavigationRoot(self.context)
        brains = self.context.portal_catalog(path={'query':subsite_path, 'depth':0})
        if brains:
            subsite = brains[0]
            registry_url = subsite.getURL() + '/portal_javascripts'
        else:
            registry_url = registry.absolute_url()
        return registry_url

    def scripts(self):
        registry = self.registry()
        registry_url = self._getRegistryURL(registry)
        context = aq_inner(self.context)

        scripts = registry.getEvaluatedResources(context)
        skinname = url_quote(self.skinname())
        result = []
        for script in scripts:
            inline = bool(script.getInline())
            if inline:
                content = registry.getInlineResource(script.getId(), context)
                data = {'inline': inline,
                        'conditionalcomment' : script.getConditionalcomment(),
                        'content': content}
            else:
                if script.isExternalResource():
                    src = "%s" % (script.getId(),)
                else:
                    src = "%s/%s/%s" % (registry_url, skinname, script.getId())
                data = {'inline': inline,
                        'conditionalcomment' : script.getConditionalcomment(),
                        'src': src}
            result.append(data)
        return result



# -*- coding: utf-8 -*-

from ZPublisher.BaseRequest import DefaultPublishTraverse
from plone.app.layout.navigation.interfaces import INavigationRoot
from zope import interface
from zope.publisher.interfaces import IPublishTraverse
from redturtle.subsites.frontend.browser.interfaces import IFrontendLayer

class NavigationRootTraverser(object):
    """Adapter for the navigation traverser using subsites"""

    interface.implements(IPublishTraverse)
    def __init__(self,context,request):
        self.default = DefaultPublishTraverse(context,request)
        self.context = context
        self.request = request

    def publishTraverse(self, request, name):
        obj = self.default.publishTraverse(request, name)
        context = self.context
        if IFrontendLayer.providedBy(request) and not INavigationRoot.providedBy(context):
            interface.alsoProvides(context, INavigationRoot)
        elif not IFrontendLayer.providedBy(request) and INavigationRoot.providedBy(context):
            interface.noLongerProvides(context, INavigationRoot)
        return obj



# -*- coding: utf-8 -*-

from zope import interface
from zope.app.content.interfaces import IContentType
#from plone.app.layout.navigation.interfaces import INavigationRoot

class ISubsiteRoot(interface.Interface):
    """Interface for a subsite folder"""

interface.alsoProvides(ISubsiteRoot,
                       IContentType)